@@ -1,7 +1,6 @@
 import config from 'config';
 
-import { RemoteCallFailedError } from '@tamanu/shared/errors';
-import { getResponseJsonSafely } from '@tamanu/shared/utils';
+import { extractErrorFromFetchResponse } from '@tamanu/errors';
 import { log } from '@tamanu/shared/services/logging';
 
 /**
@@ -33,24 +32,17 @@ export class FacilitySyncConnection {
     });
 
     if (!response.ok) {
-      const responseBody = await getResponseJsonSafely(response);
-      const { error } = responseBody;
-
-      const errorMessage = error ? error.message : 'no error message given';
-      const err = new RemoteCallFailedError(
-        `Faciliy Sync API responded with status code ${response.status} (${errorMessage})`,
-      );
-      throw err;
+      throw await extractErrorFromFetchResponse(response, url, log);
     }
 
-    return response.json();
+    return await response.json();
   }
 
   async runSync(syncData) {
-    return this.fetch('run', { method: 'POST', body: { syncData } });
+    return await this.fetch('run', { method: 'POST', body: { syncData } });
   }
 
   async getSyncStatus() {
-    return this.fetch('status');
+    return await this.fetch('status');
   }
 }
